Changelog
=========

Only important changes are mentioned below.


v0.2 (2014-07-xx)
-----------------

* Improved documentation
* Avoid using a global registry for registered apps in favour of a setting variable


v0.1 (2014-07-18)
-----------------

* First stable version released
